@@ -5,10 +5,10 @@ use crate::consts::TREESITTER_CMAKE_LANGUAGE;
 use crate::fileapi;
 use crate::languageserver::BUFFERS_CACHE;
 use crate::scansubs::TREE_MAP;
-use crate::utils::treehelper::{get_pos_type, position_to_point, PositionType};
+use crate::utils::treehelper::{get_pos_type, PositionType, ToPoint};
 use crate::utils::{
-    gen_module_pattern, remove_quotation_and_replace_placeholders, LineCommentTmp,
-    CACHE_CMAKE_PACKAGES_WITHKEYS,
+    gen_module_pattern, include_is_module, remove_quotation_and_replace_placeholders,
+    LineCommentTmp, CACHE_CMAKE_PACKAGES_WITHKEYS,
 };
 use buildin::{BUILDIN_COMMAND, BUILDIN_MODULE, BUILDIN_VARIABLE};
 use std::collections::HashMap;
@@ -115,17 +115,18 @@ pub async fn getcomplete(
     let thetree = parse.parse(source, None);
     let tree = thetree.unwrap();
     let mut complete: Vec<CompletionItem> = vec![];
-    let mut cached_compeletion = get_cached_completion(local_path).await;
-    if !cached_compeletion.is_empty() {
-        complete.append(&mut cached_compeletion);
-    }
-    if let Some(mut cmake_cache) = fileapi::get_complete_data() {
-        complete.append(&mut cmake_cache);
-    }
-    let current_point = position_to_point(location);
+
+    let current_point = location.to_point();
     let postype = get_pos_type(current_point, tree.root_node(), source);
     match postype {
         PositionType::VarOrFun | PositionType::TargetLink | PositionType::TargetInclude => {
+            let mut cached_compeletion = get_cached_completion(local_path).await;
+            if !cached_compeletion.is_empty() {
+                complete.append(&mut cached_compeletion);
+            }
+            if let Some(mut cmake_cache) = fileapi::get_complete_data() {
+                complete.append(&mut cmake_cache);
+            }
             if let Some(mut message) = getsubcomplete(
                 tree.root_node(),
                 &source.lines().collect(),
@@ -158,6 +159,13 @@ pub async fn getcomplete(
             complete.append(&mut findpackage::PKGCONFIG_SOURCE.clone());
         }
         PositionType::Include => {
+            let mut cached_compeletion = get_cached_completion(local_path).await;
+            if !cached_compeletion.is_empty() {
+                complete.append(&mut cached_compeletion);
+            }
+            if let Some(mut cmake_cache) = fileapi::get_complete_data() {
+                complete.append(&mut cmake_cache);
+            }
             if let Ok(messages) = &*BUILDIN_MODULE {
                 complete.append(&mut messages.clone());
             }
@@ -181,10 +189,10 @@ pub async fn getcomplete(
 /// get the variable from the loop
 /// use position to make only can complete which has show before
 #[allow(clippy::too_many_arguments)]
-fn getsubcomplete(
+fn getsubcomplete<P: AsRef<Path>>(
     input: tree_sitter::Node,
     source: &Vec<&str>,
-    local_path: &Path,
+    local_path: P,
     postype: PositionType,
     location: Option<Position>,
     include_files: &mut Vec<PathBuf>,
@@ -196,6 +204,7 @@ fn getsubcomplete(
         postype,
         PositionType::VarOrFun | PositionType::TargetLink | PositionType::TargetInclude
     ));
+    let local_path = local_path.as_ref();
     if let Some(location) = location {
         if input.start_position().row as u32 > location.line {
             return None;
@@ -329,7 +338,7 @@ fn getsubcomplete(
                             continue;
                         };
                         let (is_buildin, subpath) = {
-                            if name.split('.').count() != 1 {
+                            if !include_is_module(&name) {
                                 (false, local_path.parent().unwrap().join(name))
                             } else {
                                 let Some(glob_pattern) = gen_module_pattern(&name) else {
@@ -533,8 +542,7 @@ fn getsubcomplete(
                     if name == "pkg_check_modules" && child.child_count() >= 3 {
                         use crate::utils::get_node_content;
                         let ids = child.child(2).unwrap();
-                        let names = get_node_content(source, &ids);
-                        let package_names: Vec<&str> = names.split(' ').collect();
+                        let package_names = get_node_content(source, &ids);
                         let package_name = package_names[0];
 
                         let modernpkgconfig = package_names.contains(&PKG_IMPORT_TARGET);
