@@ -9,7 +9,11 @@ use std::sync::Arc;
 use std::sync::LazyLock;
 use tokio::sync::Mutex;
 
-use crate::consts::TREESITTER_CMAKE_LANGUAGE;
+use crate::{
+    consts::TREESITTER_CMAKE_LANGUAGE,
+    utils::{remove_quotation, remove_quotation_and_replace_placeholders},
+    CMakeNodeKinds,
+};
 
 /// NOTE: key is be included path, value is the top CMakeLists
 /// This is used to find who is on the top of the CMakeLists
@@ -63,10 +67,9 @@ fn scan_node<P: AsRef<Path>>(source: &Vec<&str>, tree: tree_sitter::Node, path:
     let mut course = tree.walk();
     for node in tree.children(&mut course) {
         match node.kind() {
-            "normal_command" => {
+            CMakeNodeKinds::NORMAL_COMMAND => {
                 let h = node.start_position().row;
                 let ids = node.child(0).unwrap();
-                //let ids = ids.child(2).unwrap();
                 let x = ids.start_position().column;
                 let y = ids.end_position().column;
                 let command_name = &source[h][x..y];
@@ -77,7 +80,9 @@ fn scan_node<P: AsRef<Path>>(source: &Vec<&str>, tree: tree_sitter::Node, path:
                         let x = ids.start_position().column;
                         let y = ids.end_position().column;
                         let name = &source[h][x..y];
-                        let name = remove_quotation(name);
+                        let Some(name) = remove_quotation_and_replace_placeholders(name) else {
+                            continue;
+                        };
                         let subpath = path
                             .as_ref()
                             .parent()
@@ -88,7 +93,7 @@ fn scan_node<P: AsRef<Path>>(source: &Vec<&str>, tree: tree_sitter::Node, path:
                     }
                 }
             }
-            "if_condition" | "foreach_loop" | "body" => {
+            CMakeNodeKinds::IF_CONDITION | CMakeNodeKinds::FOREACH_LOOP | CMakeNodeKinds::BODY => {
                 bufs.append(&mut scan_node(source, node, path.as_ref()));
             }
             _ => {}
@@ -97,18 +102,18 @@ fn scan_node<P: AsRef<Path>>(source: &Vec<&str>, tree: tree_sitter::Node, path:
     bufs
 }
 
-#[derive(Deserialize, Debug, Serialize, Clone)]
+#[derive(Deserialize, Debug, Serialize, Clone, PartialEq, Eq)]
 pub struct TreeDir {
-    dir: PathBuf,
+    current_file: PathBuf,
     subdirs: Option<Vec<TreeDir>>,
 }
 
 impl fmt::Display for TreeDir {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match &self.subdirs {
-            None => writeln!(f, "{}", self.dir.display()),
+            None => writeln!(f, "{}", self.current_file.display()),
             Some(dirs) => {
-                writeln!(f, "{}", self.dir.display())?;
+                writeln!(f, "{}", self.current_file.display())?;
                 for dir in dirs {
                     let message = dir.to_string();
                     for mes in message.lines() {
@@ -127,7 +132,7 @@ pub fn get_treedir(path: &Path) -> Option<TreeDir> {
         return None;
     };
     let mut top = TreeDir {
-        dir: path.into(),
+        current_file: path.into(),
         subdirs: None,
     };
     let mut parse = tree_sitter::Parser::new();
@@ -154,57 +159,84 @@ fn get_subdir_from_tree(
     parent: &Path,
 ) -> Vec<PathBuf> {
     if tree.is_error() {
-        vec![]
-    } else {
-        let mut course = tree.walk();
-        let mut output = vec![];
-        for node in tree.children(&mut course) {
-            let mut innodepath = get_subdir_from_tree(source, node, parent);
-            if !innodepath.is_empty() {
-                output.append(&mut innodepath);
-            }
-            if node.kind() == "normal_command" {
-                let h = node.start_position().row;
-                let ids = node.child(0).unwrap();
-                //let ids = ids.child(2).unwrap();
-                let x = ids.start_position().column;
-                let y = ids.end_position().column;
-                let command_name = &source[h][x..y];
-                if command_name.to_lowercase() == "add_subdirectory" && node.child_count() >= 4 {
-                    let ids = node.child(2).unwrap();
-                    if ids.start_position().row == ids.end_position().row {
-                        let h = ids.start_position().row;
-                        let x = ids.start_position().column;
-                        let y = ids.end_position().column;
-                        let name = &source[h][x..y];
-                        let name = remove_quotation(name);
-                        let subpath = parent.parent().unwrap().join(name).join("CMakeLists.txt");
-                        if subpath.exists() {
-                            output.push(subpath);
-                        }
+        return vec![];
+    }
+    let mut course = tree.walk();
+    let mut output = vec![];
+    for node in tree.children(&mut course) {
+        let mut innodepath = get_subdir_from_tree(source, node, parent);
+        if !innodepath.is_empty() {
+            output.append(&mut innodepath);
+        }
+        if node.kind() == CMakeNodeKinds::NORMAL_COMMAND {
+            let h = node.start_position().row;
+            let ids = node.child(0).unwrap();
+            //let ids = ids.child(2).unwrap();
+            let x = ids.start_position().column;
+            let y = ids.end_position().column;
+            let command_name = &source[h][x..y];
+            if command_name.to_lowercase() == "add_subdirectory" && node.child_count() >= 4 {
+                let ids = node.child(2).unwrap();
+                if ids.start_position().row == ids.end_position().row {
+                    let h = ids.start_position().row;
+                    let x = ids.start_position().column;
+                    let y = ids.end_position().column;
+                    let name = &source[h][x..y];
+                    let name = remove_quotation(name);
+                    let subpath = parent.parent().unwrap().join(name).join("CMakeLists.txt");
+                    if subpath.exists() {
+                        output.push(subpath);
                     }
                 }
             }
         }
-        output
     }
+    output
 }
 
-fn remove_quotation(input: &str) -> &str {
-    if input.split('"').count() == 3 {
-        input.split('"').collect::<Vec<&str>>()[1]
-    } else {
-        input
-    }
+#[tokio::test]
+async fn test_scan_sub() {
+    use std::fs;
+    use std::fs::File;
+    use std::io::Write;
+    use tempfile::tempdir;
+    let dir = tempdir().unwrap();
+    let top_cmake = dir.path().join("CMakeLists.txt");
+    let mut top_file = File::create_new(&top_cmake).unwrap();
+    writeln!(top_file, r#"add_subdirectory("abcd_test")"#).unwrap();
+    let subdir = dir.path().join("abcd_test");
+    fs::create_dir_all(&subdir).unwrap();
+    let subdir_file = subdir.join("CMakeLists.txt");
+    File::create_new(&subdir_file).unwrap();
+    let bufs = scan_dir(&top_cmake).await;
+    assert_eq!(bufs, vec![subdir_file.clone()]);
+    let cache_data = TREE_MAP.lock().await;
+    assert_eq!(*cache_data, HashMap::from_iter([(subdir_file, top_cmake)]));
 }
 
 #[test]
-fn tst_quotantion() {
-    let a = r#"
-    "aa"
-    "#;
-    assert_eq!("aa", remove_quotation(a));
-
-    let b = "sdfds";
-    assert_eq!(b, "sdfds");
+fn test_tree_dir() {
+    use std::fs;
+    use std::fs::File;
+    use std::io::Write;
+    use tempfile::tempdir;
+    let dir = tempdir().unwrap();
+    let top_cmake = dir.path().join("CMakeLists.txt");
+    let mut top_file = File::create_new(&top_cmake).unwrap();
+    writeln!(top_file, r#"add_subdirectory("abcd_test")"#).unwrap();
+    let subdir = dir.path().join("abcd_test");
+    fs::create_dir_all(&subdir).unwrap();
+    let subdir_file = subdir.join("CMakeLists.txt");
+    File::create_new(&subdir_file).unwrap();
+    let tree_dir = get_treedir(&top_cmake).unwrap();
+    assert_eq!(
+        tree_dir,
+        TreeDir {
+            current_file: top_cmake,
+            subdirs: Some(vec![TreeDir {
+                current_file: subdir_file,
+                subdirs: None,
+            }])
+        }
+    )
 }
