@@ -32,6 +32,62 @@ pub use cmakepackage::*;
 pub use vcpkg::*;
 
 use std::{collections::HashMap, sync::LazyLock};
+
+fn handle_config_package(filename: &str) -> Option<&str> {
+    if let Some(tryfirst) = filename.strip_suffix("-config.cmake") {
+        return Some(tryfirst);
+    }
+    filename.strip_suffix("Config.cmake")
+}
+
+#[test]
+fn handle_config_package_tst() {
+    let test_file = "libaec-config.cmake";
+    let tst_file = handle_config_package(&test_file).unwrap();
+    assert_eq!(tst_file, "libaec");
+}
+
+static SPECIAL_PACKAGE_PATTERN: LazyLock<regex::Regex> =
+    LazyLock::new(|| regex::Regex::new(r"([a-zA-Z_\d\-]+)-(\d+(\.\d+)*)").unwrap());
+
+#[test]
+fn special_package_pattern_tst() {
+    let matched_pattern = "boost_atomic-1.86.0";
+    assert!(SPECIAL_PACKAGE_PATTERN.is_match(matched_pattern));
+    let captures = SPECIAL_PACKAGE_PATTERN.captures(&matched_pattern).unwrap();
+    assert_eq!(captures.get(1).unwrap().as_str(), "boost_atomic");
+    assert_eq!(captures.get(2).unwrap().as_str(), "1.86.0");
+
+    let matched_pattern = "QuaZip-Qt5-1.4";
+    assert!(SPECIAL_PACKAGE_PATTERN.is_match(matched_pattern));
+    let captures = SPECIAL_PACKAGE_PATTERN.captures(&matched_pattern).unwrap();
+    assert_eq!(captures.get(1).unwrap().as_str(), "QuaZip-Qt5");
+    assert_eq!(captures.get(2).unwrap().as_str(), "1.4");
+
+    let matched_pattern = "boost_atomic2-1.86.0";
+    assert!(SPECIAL_PACKAGE_PATTERN.is_match(matched_pattern));
+    let captures = SPECIAL_PACKAGE_PATTERN.captures(&matched_pattern).unwrap();
+    assert_eq!(captures.get(1).unwrap().as_str(), "boost_atomic2");
+    assert_eq!(captures.get(2).unwrap().as_str(), "1.86.0");
+
+    let matched_pattern = "mongoc-1.0";
+    assert!(SPECIAL_PACKAGE_PATTERN.is_match(matched_pattern));
+    let captures = SPECIAL_PACKAGE_PATTERN.captures(&matched_pattern).unwrap();
+    assert_eq!(captures.get(1).unwrap().as_str(), "mongoc");
+    assert_eq!(captures.get(2).unwrap().as_str(), "1.0");
+
+    let unmatched_pattern = "Qt5Core";
+
+    assert!(!SPECIAL_PACKAGE_PATTERN.is_match(unmatched_pattern));
+
+    let unmatched_pattern = "libjpeg-turbo";
+
+    assert!(!SPECIAL_PACKAGE_PATTERN.is_match(unmatched_pattern));
+
+    let unmatched_pattern = "QuaZip-Qt5";
+    assert!(!SPECIAL_PACKAGE_PATTERN.is_match(unmatched_pattern))
+}
+
 // match file xx.cmake and CMakeLists.txt
 static CMAKEREGEX: LazyLock<regex::Regex> =
     LazyLock::new(|| regex::Regex::new(r"^.+\.cmake$|CMakeLists.txt$").unwrap());
@@ -198,25 +254,22 @@ pub mod packagepkgconfig {
         let mut generatepackage = || -> anyhow::Result<()> {
             for path in QUERYSRULES.lock().unwrap().iter() {
                 for entry in glob::glob(path)?.flatten() {
-                    let p = entry.as_path().to_str().unwrap();
-                    let name = p
-                        .split('/')
-                        .collect::<Vec<&str>>()
-                        .last()
-                        .unwrap()
-                        .to_string();
-                    let realname = name
-                        .split('.')
-                        .collect::<Vec<&str>>()
-                        .first()
-                        .unwrap()
-                        .to_string();
-                    packages
-                        .entry(realname.to_string())
-                        .or_insert_with(|| PkgConfig {
-                            libname: realname,
-                            path: Url::from_file_path(p).unwrap(),
-                        });
+                    let Some(file_name) =
+                        entry.file_name().and_then(|file_name| file_name.to_str())
+                    else {
+                        continue;
+                    };
+                    let Some(realname) = file_name.strip_suffix(".pc") else {
+                        continue;
+                    };
+
+                    packages.insert(
+                        realname.to_string(),
+                        PkgConfig {
+                            libname: realname.to_string(),
+                            path: Url::from_file_path(entry).unwrap(),
+                        },
+                    );
                 }
             }
             Ok(())
