@@ -9,7 +9,10 @@ use std::sync::LazyLock;
 
 use crate::utils::{CMakePackage, CMakePackageFrom, PackageType};
 
-use super::{get_version, CMAKECONFIG, CMAKECONFIGVERSION, CMAKEREGEX};
+use super::{
+    get_version, handle_config_package, CMAKECONFIG, CMAKECONFIGVERSION, CMAKEREGEX,
+    SPECIAL_PACKAGE_PATTERN,
+};
 
 // here is the logic of findpackage on linux
 //
@@ -54,26 +57,33 @@ fn get_cmake_message() -> HashMap<String, CMakePackage> {
                     }
                 }
             }
-            if ispackage {
-                let location = Url::from_file_path(&path).unwrap();
-                let packagename = path
-                    .parent()
-                    .unwrap()
-                    .file_name()
-                    .unwrap()
-                    .to_str()
-                    .unwrap();
-                packages
-                    .entry(packagename.to_string())
-                    .or_insert_with(|| CMakePackage {
-                        name: packagename.to_string(),
-                        packagetype: PackageType::Dir,
-                        location,
-                        version,
-                        tojump,
-                        from: CMakePackageFrom::System,
-                    });
+            if !ispackage {
+                continue;
             }
+
+            let Some(parent_path) = path.parent() else {
+                continue;
+            };
+            let Some(packagename) = parent_path
+                .file_name()
+                .and_then(|file_name| file_name.to_str())
+            else {
+                continue;
+            };
+
+            let location = Url::from_file_path(&path).unwrap();
+
+            packages.insert(
+                packagename.to_string(),
+                CMakePackage {
+                    name: packagename.to_string(),
+                    packagetype: PackageType::Dir,
+                    location,
+                    version,
+                    tojump,
+                    from: CMakePackageFrom::System,
+                },
+            );
         }
     }
     for lib in get_available_libs() {
@@ -85,18 +95,19 @@ fn get_cmake_message() -> HashMap<String, CMakePackage> {
             let mut tojump: Vec<PathBuf> = vec![];
             let pathname = path.file_name().to_str().unwrap().to_string();
             let location = Url::from_file_path(path.path()).unwrap();
-            let (packagetype, packagename) = {
+            let (packagetype, mut packagename) = {
                 if path.metadata().is_ok_and(|data| data.is_dir()) {
                     let Ok(paths) = std::fs::read_dir(path.path()) else {
                         continue;
                     };
                     for path in paths.flatten() {
                         let filepath = fs::canonicalize(path.path()).unwrap();
-                        if path.metadata().unwrap().is_file() {
-                            let filename = path.file_name().to_str().unwrap().to_string();
-                            if CMAKEREGEX.is_match(&filename) {
+                        if path.metadata().is_ok_and(|metadata| metadata.is_file()) {
+                            let path_name = path.file_name();
+                            let filename = path_name.to_str().unwrap();
+                            if CMAKEREGEX.is_match(filename) {
                                 tojump.push(filepath.clone());
-                                if CMAKECONFIGVERSION.is_match(&filename) {
+                                if CMAKECONFIGVERSION.is_match(filename) {
                                     if let Ok(context) = fs::read_to_string(&filepath) {
                                         version = get_version(&context);
                                     }
@@ -108,20 +119,27 @@ fn get_cmake_message() -> HashMap<String, CMakePackage> {
                 } else {
                     let filepath = fs::canonicalize(path.path()).unwrap();
                     tojump.push(filepath);
-                    let pathname = pathname.split('.').collect::<Vec<&str>>()[0].to_string();
-                    (PackageType::File, pathname)
+                    let Some(pathname) = handle_config_package(&pathname) else {
+                        continue;
+                    };
+                    (PackageType::File, pathname.to_owned())
                 }
             };
-            packages
-                .entry(packagename.clone())
-                .or_insert_with(|| CMakePackage {
+            if let Some(captures) = SPECIAL_PACKAGE_PATTERN.captures(&packagename.clone()) {
+                packagename = captures.get(1).unwrap().as_str().to_owned();
+                version = captures.get(2).map(|version| version.as_str().to_string());
+            }
+            packages.insert(
+                packagename.clone(),
+                CMakePackage {
                     name: packagename,
                     packagetype,
                     location,
                     version,
                     tojump,
                     from: CMakePackageFrom::System,
-                });
+                },
+            );
         }
     }
     packages
